"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.external_link_pb2
import prodvana.proto.prodvana.runtimes.debug_event_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FetchMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FetchModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FetchMode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_FETCH_MODE: _FetchMode.ValueType  # 0
    EXIT_CODE: _FetchMode.ValueType  # 1
    """fetch will either exit 0 or 2 to indicate drift"""
    STRUCTURED_OUTPUT: _FetchMode.ValueType  # 2
    """fetch will return structured output via stdout"""

class FetchMode(_FetchMode, metaclass=_FetchModeEnumTypeWrapper): ...

UNKNOWN_FETCH_MODE: FetchMode.ValueType  # 0
EXIT_CODE: FetchMode.ValueType  # 1
"""fetch will either exit 0 or 2 to indicate drift"""
STRUCTURED_OUTPUT: FetchMode.ValueType  # 2
"""fetch will return structured output via stdout"""
global___FetchMode = FetchMode

class ExternalObjectVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    TARGET_REPLICAS_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    DRIFTED_FIELD_NUMBER: builtins.int
    version: builtins.str
    replicas: builtins.int
    """Created/running replicas, can be in any state"""
    available_replicas: builtins.int
    """Replicas which have passed healthchecks for required duration."""
    target_replicas: builtins.int
    """How many replicas are supposed to be spun up, if known"""
    active: builtins.bool
    drifted: builtins.bool
    """next tag: 7"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        replicas: builtins.int = ...,
        available_replicas: builtins.int = ...,
        target_replicas: builtins.int = ...,
        active: builtins.bool = ...,
        drifted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "available_replicas", b"available_replicas", "drifted", b"drifted", "replicas", b"replicas", "target_replicas", b"target_replicas", "version", b"version"]) -> None: ...

global___ExternalObjectVersion = ExternalObjectVersion

class ExternalObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExternalObject._Status.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PENDING: ExternalObject._Status.ValueType  # 0
        SUCCEEDED: ExternalObject._Status.ValueType  # 1
        FAILED: ExternalObject._Status.ValueType  # 2

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    PENDING: ExternalObject.Status.ValueType  # 0
    SUCCEEDED: ExternalObject.Status.ValueType  # 1
    FAILED: ExternalObject.Status.ValueType  # 2

    NAME_FIELD_NUMBER: builtins.int
    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    EXTERNAL_LINKS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DEBUG_EVENTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    object_type: builtins.str
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExternalObjectVersion]: ...
    status: global___ExternalObject.Status.ValueType
    @property
    def external_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.external_link_pb2.ExternalLink]: ...
    message: builtins.str
    """freeform message explaining the status, for example, error message"""
    @property
    def debug_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.runtimes.debug_event_pb2.DebugEvent]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        object_type: builtins.str = ...,
        versions: collections.abc.Iterable[global___ExternalObjectVersion] | None = ...,
        status: global___ExternalObject.Status.ValueType = ...,
        external_links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.external_link_pb2.ExternalLink] | None = ...,
        message: builtins.str = ...,
        debug_events: collections.abc.Iterable[prodvana.proto.prodvana.runtimes.debug_event_pb2.DebugEvent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug_events", b"debug_events", "external_links", b"external_links", "message", b"message", "name", b"name", "object_type", b"object_type", "status", b"status", "versions", b"versions"]) -> None: ...

global___ExternalObject = ExternalObject

class FetchOutput(google.protobuf.message.Message):
    """output format for the fetch command, in json format
    optional. Fetch commands can choose to implement the output, or exit 0 or 2.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExternalObject]: ...
    def __init__(
        self,
        *,
        objects: collections.abc.Iterable[global___ExternalObject] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["objects", b"objects"]) -> None: ...

global___FetchOutput = FetchOutput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/protection_reference.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/protection/protection_reference.proto\x12\x13prodvana.protection\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\x1a\'prodvana/common_config/parameters.proto\"\x9c\x04\n\x13ProtectionLifecycle\x12L\n\x0cpre_approval\x18\x01 \x01(\x0b\x32\x34.prodvana.protection.ProtectionLifecycle.PreApprovalH\x00\x12N\n\rpost_approval\x18\x03 \x01(\x0b\x32\x35.prodvana.protection.ProtectionLifecycle.PostApprovalH\x00\x12I\n\ndeployment\x18\x04 \x01(\x0b\x32\x33.prodvana.protection.ProtectionLifecycle.DeploymentH\x00\x12R\n\x0fpost_deployment\x18\x05 \x01(\x0b\x32\x37.prodvana.protection.ProtectionLifecycle.PostDeploymentH\x00\x1a\r\n\x0bPreApproval\x1a\x0e\n\x0cPostApproval\x1a\x0c\n\nDeployment\x1a\x88\x01\n\x0ePostDeployment\x12\x37\n\x14\x64\x65lay_check_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x0e\x63heck_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x42\x10\n\tlifecycle\x12\x03\xf8\x42\x01\"\x9c\x01\n\x13ProtectionReference\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\nparameters\x18\x03 \x03(\x0b\x32&.prodvana.common_config.ParameterValueJ\x04\x08\x02\x10\x03R\x08\x61ttachedBOZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.protection_reference_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _PROTECTIONLIFECYCLE_POSTDEPLOYMENT.fields_by_name['check_duration']._options = None
  _PROTECTIONLIFECYCLE_POSTDEPLOYMENT.fields_by_name['check_duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _PROTECTIONLIFECYCLE.oneofs_by_name['lifecycle']._options = None
  _PROTECTIONLIFECYCLE.oneofs_by_name['lifecycle']._serialized_options = b'\370B\001'
  _PROTECTIONREFERENCE.fields_by_name['name']._options = None
  _PROTECTIONREFERENCE.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _globals['_PROTECTIONLIFECYCLE']._serialized_start=170
  _globals['_PROTECTIONLIFECYCLE']._serialized_end=710
  _globals['_PROTECTIONLIFECYCLE_PREAPPROVAL']._serialized_start=510
  _globals['_PROTECTIONLIFECYCLE_PREAPPROVAL']._serialized_end=523
  _globals['_PROTECTIONLIFECYCLE_POSTAPPROVAL']._serialized_start=525
  _globals['_PROTECTIONLIFECYCLE_POSTAPPROVAL']._serialized_end=539
  _globals['_PROTECTIONLIFECYCLE_DEPLOYMENT']._serialized_start=541
  _globals['_PROTECTIONLIFECYCLE_DEPLOYMENT']._serialized_end=553
  _globals['_PROTECTIONLIFECYCLE_POSTDEPLOYMENT']._serialized_start=556
  _globals['_PROTECTIONLIFECYCLE_POSTDEPLOYMENT']._serialized_end=692
  _globals['_PROTECTIONREFERENCE']._serialized_start=713
  _globals['_PROTECTIONREFERENCE']._serialized_end=869
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pvn_wrapper/job_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.pvn_wrapper import output_pb2 as prodvana_dot_pvn__wrapper_dot_output__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/pvn_wrapper/job_manager.proto\x12\x14prodvana.pvn_wrapper\x1a!prodvana/pvn_wrapper/output.proto\"R\n\x12ReportJobResultReq\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12,\n\x06output\x18\x02 \x01(\x0b\x32\x1c.prodvana.pvn_wrapper.Output\"\x15\n\x13ReportJobResultResp2t\n\nJobManager\x12\x66\n\x0fReportJobResult\x12(.prodvana.pvn_wrapper.ReportJobResultReq\x1a).prodvana.pvn_wrapper.ReportJobResultRespBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapperb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pvn_wrapper.job_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapper'
  _globals['_REPORTJOBRESULTREQ']._serialized_start=99
  _globals['_REPORTJOBRESULTREQ']._serialized_end=181
  _globals['_REPORTJOBRESULTRESP']._serialized_start=183
  _globals['_REPORTJOBRESULTRESP']._serialized_end=204
  _globals['_JOBMANAGER']._serialized_start=206
  _globals['_JOBMANAGER']._serialized_end=322
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RemoteHelmChart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPO_FIELD_NUMBER: builtins.int
    CHART_FIELD_NUMBER: builtins.int
    CHART_VERSION_FIELD_NUMBER: builtins.int
    repo: builtins.str
    """TODO(naphat) add integration support for private repositories"""
    chart: builtins.str
    chart_version: builtins.str
    def __init__(
        self,
        *,
        repo: builtins.str = ...,
        chart: builtins.str = ...,
        chart_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repo", b"repo", "repo_oneof", b"repo_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chart", b"chart", "chart_version", b"chart_version", "repo", b"repo", "repo_oneof", b"repo_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["repo_oneof", b"repo_oneof"]) -> typing_extensions.Literal["repo"] | None: ...

global___RemoteHelmChart = RemoteHelmChart

class HelmValuesOverrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    inlined: builtins.str
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    @property
    def remote(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig: ...
    def __init__(
        self,
        *,
        inlined: builtins.str = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        remote: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "override_oneof", b"override_oneof", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "override_oneof", b"override_oneof", "remote", b"remote"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["override_oneof", b"override_oneof"]) -> typing_extensions.Literal["inlined", "local", "remote"] | None: ...

global___HelmValuesOverrides = HelmValuesOverrides

class HelmConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMOTE_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    HELM_TARBALL_BLOB_ID_FIELD_NUMBER: builtins.int
    VALUES_OVERRIDES_FIELD_NUMBER: builtins.int
    RELEASE_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    FIXUP_OWNERSHIP_FIELD_NUMBER: builtins.int
    @property
    def remote(self) -> global___RemoteHelmChart: ...
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    helm_tarball_blob_id: builtins.str
    @property
    def values_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HelmValuesOverrides]: ...
    release_name: builtins.str
    """optional release name, leave blank to have Prodvana generate one.
    Mainly useful for migrating an existing helm release into Prodvana.
    """
    namespace: builtins.str
    """used internally by Prodvana, do not set."""
    fixup_ownership: builtins.bool
    """Before running helm commands, first fixup labels and annotations of the Kubernetes objects
    to match the expected state. This is useful for migrating an existing Kubernetes object to be managed
    by Helm.
    """
    def __init__(
        self,
        *,
        remote: global___RemoteHelmChart | None = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        helm_tarball_blob_id: builtins.str = ...,
        values_overrides: collections.abc.Iterable[global___HelmValuesOverrides] | None = ...,
        release_name: builtins.str = ...,
        namespace: builtins.str = ...,
        fixup_ownership: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chart_oneof", b"chart_oneof", "helm_tarball_blob_id", b"helm_tarball_blob_id", "local", b"local", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chart_oneof", b"chart_oneof", "fixup_ownership", b"fixup_ownership", "helm_tarball_blob_id", b"helm_tarball_blob_id", "local", b"local", "namespace", b"namespace", "release_name", b"release_name", "remote", b"remote", "values_overrides", b"values_overrides"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["chart_oneof", b"chart_oneof"]) -> typing_extensions.Literal["remote", "local", "helm_tarball_blob_id"] | None: ...

global___HelmConfig = HelmConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

MEMPOOL_FIELD_NUMBER: builtins.int
UNSTABLE_FOR_EQUAL_FIELD_NUMBER: builtins.int
mempool: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unstable_for_equal: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
"""Should this field be excluded from the generated StableEqualVT method?"""



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import prodvana.proto.prodvana.pvn_wrapper.output_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReportJobResultReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    @property
    def output(self) -> prodvana.proto.prodvana.pvn_wrapper.output_pb2.Output: ...
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        output: prodvana.proto.prodvana.pvn_wrapper.output_pb2.Output | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id", "output", b"output"]) -> None: ...

global___ReportJobResultReq = ReportJobResultReq

class ReportJobResultResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportJobResultResp = ReportJobResultResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/volumes/volumes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/volumes/volumes.proto\x12\x10prodvana.volumes\x1a\x17validate/validate.proto\"\xd5\x02\n\x0cVolumeSource\x12=\n\x06secret\x18\x01 \x01(\x0b\x32+.prodvana.volumes.VolumeSource.SecretSourceH\x00\x12\x43\n\tephemeral\x18\x02 \x01(\x0b\x32..prodvana.volumes.VolumeSource.EphemeralSourceH\x00\x1a,\n\x0cSecretSource\x12\x1c\n\x0bsecret_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x88\x01\n\x0f\x45phemeralSource\x12\x45\n\x06medium\x18\x01 \x01(\x0e\x32\x35.prodvana.volumes.VolumeSource.EphemeralSource.Medium\".\n\x06Medium\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\n\n\x06MEMORY\x10\x02\x42\x08\n\x06source\"4\n\x0bVolumeMount\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\"}\n\x06Volume\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12.\n\x06source\x18\x02 \x01(\x0b\x32\x1e.prodvana.volumes.VolumeSource\x12,\n\x05mount\x18\x03 \x01(\x0b\x32\x1d.prodvana.volumes.VolumeMountBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/volumesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.volumes.volumes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/volumes'
  _VOLUMESOURCE_SECRETSOURCE.fields_by_name['secret_name']._options = None
  _VOLUMESOURCE_SECRETSOURCE.fields_by_name['secret_name']._serialized_options = b'\372B\004r\002\020\001'
  _VOLUME.fields_by_name['name']._options = None
  _VOLUME.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_VOLUMESOURCE']._serialized_start=78
  _globals['_VOLUMESOURCE']._serialized_end=419
  _globals['_VOLUMESOURCE_SECRETSOURCE']._serialized_start=226
  _globals['_VOLUMESOURCE_SECRETSOURCE']._serialized_end=270
  _globals['_VOLUMESOURCE_EPHEMERALSOURCE']._serialized_start=273
  _globals['_VOLUMESOURCE_EPHEMERALSOURCE']._serialized_end=409
  _globals['_VOLUMESOURCE_EPHEMERALSOURCE_MEDIUM']._serialized_start=363
  _globals['_VOLUMESOURCE_EPHEMERALSOURCE_MEDIUM']._serialized_end=409
  _globals['_VOLUMEMOUNT']._serialized_start=421
  _globals['_VOLUMEMOUNT']._serialized_end=473
  _globals['_VOLUME']._serialized_start=475
  _globals['_VOLUME']._serialized_end=600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/agent/agent_interaction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/agent/agent_interaction.proto\x12\x0eprodvana.agent\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#prodvana/environment/clusters.proto\"\"\n\x0cHeartbeatReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x0f\n\rHeartbeatResp\"\x95\x01\n\x17RecordNewUnknownPushReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1a\n\x18RecordNewUnknownPushResp\"\xc5\x01\n\x12RecordPushStartReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x15\n\x13RecordPushStartResp\"\x92\x01\n\x14RecordPushOngoingReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"\x17\n\x15RecordPushOngoingResp\"\x82\x02\n\x15RecordPushCompleteReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.prodvana.agent.RecordPushCompleteReq.Type\"3\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x0f\n\x0bROLLED_BACK\x10\x02\"\x18\n\x16RecordPushCompleteResp\"\x94\x01\n\x16\x43onfirmPushApprovalReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"+\n\x17\x43onfirmPushApprovalResp\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\"_\n\x0cRecordPodReq\x12\x0b\n\x03pod\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\x12\x12\n\nruntime_id\x18\x03 \x01(\t\"\x0f\n\rRecordPodResp\"1\n\rRecordPodsReq\x12\x0c\n\x04pods\x18\x01 \x03(\x0c\x12\x12\n\nruntime_id\x18\x02 \x01(\t\"\x10\n\x0eRecordPodsResp\"Y\n\x13RecordDeploymentReq\x12\x12\n\ndeployment\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"J\n\x14RecordDeploymentResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x10RecordRolloutReq\x12\x0f\n\x07rollout\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"G\n\x11RecordRolloutResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Q\n\x11ProxyAPIServerReq\x12\x14\n\nruntime_id\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\x12\x0f\n\x07\x63onn_id\x18\x03 \x01(\tB\x05\n\x03msg\"\x8e\x01\n\x12ProxyAPIServerResp\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32\'.prodvana.agent.ProxyAPIServerResp.TypeH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\"(\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fPROXY_APISERVER\x10\x01\x42\x05\n\x03msg\"5\n\tDebugInfo\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x19\n\x11tcptraceroute_out\x18\x02 \x01(\t\"Q\n\x12ReportDebugInfoReq\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\'\n\x04info\x18\x02 \x01(\x0b\x32\x19.prodvana.agent.DebugInfo\"\x15\n\x13ReportDebugInfoResp\"~\n\x18ReportClusterMetadataReq\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12?\n\x10\x63luster_metadata\x18\x02 \x01(\x0b\x32%.prodvana.environment.ClusterMetadata\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\x1b\n\x19ReportClusterMetadataResp*1\n\x0eInformerAction\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x32\xf1\t\n\x10\x41gentInteraction\x12J\n\tHeartbeat\x12\x1c.prodvana.agent.HeartbeatReq\x1a\x1d.prodvana.agent.HeartbeatResp\"\x00\x12h\n\x13\x43onfirmPushApproval\x12&.prodvana.agent.ConfirmPushApprovalReq\x1a\'.prodvana.agent.ConfirmPushApprovalResp\"\x00\x12k\n\x14RecordNewUnknownPush\x12\'.prodvana.agent.RecordNewUnknownPushReq\x1a(.prodvana.agent.RecordNewUnknownPushResp\"\x00\x12\\\n\x0fRecordPushStart\x12\".prodvana.agent.RecordPushStartReq\x1a#.prodvana.agent.RecordPushStartResp\"\x00\x12\x62\n\x11RecordPushOngoing\x12$.prodvana.agent.RecordPushOngoingReq\x1a%.prodvana.agent.RecordPushOngoingResp\"\x00\x12\x65\n\x12RecordPushComplete\x12%.prodvana.agent.RecordPushCompleteReq\x1a&.prodvana.agent.RecordPushCompleteResp\"\x00\x12J\n\tRecordPod\x12\x1c.prodvana.agent.RecordPodReq\x1a\x1d.prodvana.agent.RecordPodResp\"\x00\x12M\n\nRecordPods\x12\x1d.prodvana.agent.RecordPodsReq\x1a\x1e.prodvana.agent.RecordPodsResp\"\x00\x12_\n\x10RecordDeployment\x12#.prodvana.agent.RecordDeploymentReq\x1a$.prodvana.agent.RecordDeploymentResp\"\x00\x12V\n\rRecordRollout\x12 .prodvana.agent.RecordRolloutReq\x1a!.prodvana.agent.RecordRolloutResp\"\x00\x12]\n\x0eProxyAPIServer\x12!.prodvana.agent.ProxyAPIServerReq\x1a\".prodvana.agent.ProxyAPIServerResp\"\x00(\x01\x30\x01\x12\\\n\x0fReportDebugInfo\x12\".prodvana.agent.ReportDebugInfoReq\x1a#.prodvana.agent.ReportDebugInfoResp\"\x00\x12n\n\x15ReportClusterMetadata\x12(.prodvana.agent.ReportClusterMetadataReq\x1a).prodvana.agent.ReportClusterMetadataResp\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALBJZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.agent.agent_interaction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agent'
  _AGENTINTERACTION._options = None
  _AGENTINTERACTION._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _globals['_INFORMERACTION']._serialized_start=2324
  _globals['_INFORMERACTION']._serialized_end=2373
  _globals['_HEARTBEATREQ']._serialized_start=157
  _globals['_HEARTBEATREQ']._serialized_end=191
  _globals['_HEARTBEATRESP']._serialized_start=193
  _globals['_HEARTBEATRESP']._serialized_end=208
  _globals['_RECORDNEWUNKNOWNPUSHREQ']._serialized_start=211
  _globals['_RECORDNEWUNKNOWNPUSHREQ']._serialized_end=360
  _globals['_RECORDNEWUNKNOWNPUSHRESP']._serialized_start=362
  _globals['_RECORDNEWUNKNOWNPUSHRESP']._serialized_end=388
  _globals['_RECORDPUSHSTARTREQ']._serialized_start=391
  _globals['_RECORDPUSHSTARTREQ']._serialized_end=588
  _globals['_RECORDPUSHSTARTRESP']._serialized_start=590
  _globals['_RECORDPUSHSTARTRESP']._serialized_end=611
  _globals['_RECORDPUSHONGOINGREQ']._serialized_start=614
  _globals['_RECORDPUSHONGOINGREQ']._serialized_end=760
  _globals['_RECORDPUSHONGOINGRESP']._serialized_start=762
  _globals['_RECORDPUSHONGOINGRESP']._serialized_end=785
  _globals['_RECORDPUSHCOMPLETEREQ']._serialized_start=788
  _globals['_RECORDPUSHCOMPLETEREQ']._serialized_end=1046
  _globals['_RECORDPUSHCOMPLETEREQ_TYPE']._serialized_start=995
  _globals['_RECORDPUSHCOMPLETEREQ_TYPE']._serialized_end=1046
  _globals['_RECORDPUSHCOMPLETERESP']._serialized_start=1048
  _globals['_RECORDPUSHCOMPLETERESP']._serialized_end=1072
  _globals['_CONFIRMPUSHAPPROVALREQ']._serialized_start=1075
  _globals['_CONFIRMPUSHAPPROVALREQ']._serialized_end=1223
  _globals['_CONFIRMPUSHAPPROVALRESP']._serialized_start=1225
  _globals['_CONFIRMPUSHAPPROVALRESP']._serialized_end=1268
  _globals['_RECORDPODREQ']._serialized_start=1270
  _globals['_RECORDPODREQ']._serialized_end=1365
  _globals['_RECORDPODRESP']._serialized_start=1367
  _globals['_RECORDPODRESP']._serialized_end=1382
  _globals['_RECORDPODSREQ']._serialized_start=1384
  _globals['_RECORDPODSREQ']._serialized_end=1433
  _globals['_RECORDPODSRESP']._serialized_start=1435
  _globals['_RECORDPODSRESP']._serialized_end=1451
  _globals['_RECORDDEPLOYMENTREQ']._serialized_start=1453
  _globals['_RECORDDEPLOYMENTREQ']._serialized_end=1542
  _globals['_RECORDDEPLOYMENTRESP']._serialized_start=1544
  _globals['_RECORDDEPLOYMENTRESP']._serialized_end=1618
  _globals['_RECORDROLLOUTREQ']._serialized_start=1620
  _globals['_RECORDROLLOUTREQ']._serialized_end=1703
  _globals['_RECORDROLLOUTRESP']._serialized_start=1705
  _globals['_RECORDROLLOUTRESP']._serialized_end=1776
  _globals['_PROXYAPISERVERREQ']._serialized_start=1778
  _globals['_PROXYAPISERVERREQ']._serialized_end=1859
  _globals['_PROXYAPISERVERRESP']._serialized_start=1862
  _globals['_PROXYAPISERVERRESP']._serialized_end=2004
  _globals['_PROXYAPISERVERRESP_TYPE']._serialized_start=1957
  _globals['_PROXYAPISERVERRESP_TYPE']._serialized_end=1997
  _globals['_DEBUGINFO']._serialized_start=2006
  _globals['_DEBUGINFO']._serialized_end=2059
  _globals['_REPORTDEBUGINFOREQ']._serialized_start=2061
  _globals['_REPORTDEBUGINFOREQ']._serialized_end=2142
  _globals['_REPORTDEBUGINFORESP']._serialized_start=2144
  _globals['_REPORTDEBUGINFORESP']._serialized_end=2165
  _globals['_REPORTCLUSTERMETADATAREQ']._serialized_start=2167
  _globals['_REPORTCLUSTERMETADATAREQ']._serialized_end=2293
  _globals['_REPORTCLUSTERMETADATARESP']._serialized_start=2295
  _globals['_REPORTCLUSTERMETADATARESP']._serialized_end=2322
  _globals['_AGENTINTERACTION']._serialized_start=2376
  _globals['_AGENTINTERACTION']._serialized_end=3641
# @@protoc_insertion_point(module_scope)
